==> qore-xml-module-1.2.tar.bz2: qore-xml-module-1.2/docs/xml/html/group__xml__functions.js <==
var group__xml__functions =
[
    [ "makeFormattedXMLFragment", "group__xml__functions.html#ga61c025d0a34bc19c4a90a8c29cb2e0e2", null ],
    [ "makeFormattedXMLFragment", "group__xml__functions.html#gae02ad522575390d1ece4f73f629050a5", null ],
    [ "makeFormattedXMLString", "group__xml__functions.html#ga466d0cd032f54fdc36d9fcf5db64993f", null ],
    [ "makeFormattedXMLString", "group__xml__functions.html#gacc5f8aceb6d15e23b8ab5c8205c37769", null ],
    [ "makeXMLFragment", "group__xml__functions.html#ga8569ee5655449923727dfe2a7fa943fd", null ],
    [ "makeXMLFragment", "group__xml__functions.html#ga4c393f08507c08c0fe2df2910c015e99", null ],
    [ "makeXMLString", "group__xml__functions.html#gadc4a3e7a509428d15133201d8dbe3f4b", null ],
    [ "makeXMLString", "group__xml__functions.html#ga8f63aa3edc95a323192a9b8d76329ef0", null ],
    [ "parseXML", "group__xml__functions.html#ga63f87398503d3763c5e9503dd0f48c86", null ],
    [ "parseXML", "group__xml__functions.html#gaf9992355e68589537fd988a2b9a57852", null ],
    [ "parseXMLAsData", "group__xml__functions.html#gab951588a77c89c57c50e653901f3f2cf", null ],
    [ "parseXMLAsData", "group__xml__functions.html#gae14ec9f58a0d859ab53f1a14b717c81f", null ],
    [ "parseXMLAsDataWithRelaxNG", "group__xml__functions.html#gae73fdba66557c31b734b570d4e5c4336", null ],
    [ "parseXMLAsDataWithSchema", "group__xml__functions.html#ga9513c1b9e4d33955cde47225385a1b1b", null ],
    [ "parseXMLWithRelaxNG", "group__xml__functions.html#gae23f485fb7a34fc6e424e7d352a889c8", null ],
    [ "parseXMLWithSchema", "group__xml__functions.html#ga28c44488e50530f01bc5a0dff740ac22", null ]
];

==> qore-xml-module-1.3.tar.bz2: qore-xml-module-1.3/docs/xml/html/group__xml__functions.js <==
var group__xml__functions =
[
    [ "make_xml", "group__xml__functions.html#gaf80a78bf2ef8baa0ef728296e62fa039", null ],
    [ "make_xml", "group__xml__functions.html#ga0be00de7f2f7f2d94897d532494a34ee", null ],
    [ "make_xml_fragment", "group__xml__functions.html#ga015703774c6993d98d2a05a39dc105fe", null ],
    [ "makeFormattedXMLFragment", "group__xml__functions.html#ga61c025d0a34bc19c4a90a8c29cb2e0e2", null ],
    [ "makeFormattedXMLFragment", "group__xml__functions.html#gae02ad522575390d1ece4f73f629050a5", null ],
    [ "makeFormattedXMLString", "group__xml__functions.html#ga466d0cd032f54fdc36d9fcf5db64993f", null ],
    [ "makeFormattedXMLString", "group__xml__functions.html#gacc5f8aceb6d15e23b8ab5c8205c37769", null ],
    [ "makeXMLFragment", "group__xml__functions.html#ga8569ee5655449923727dfe2a7fa943fd", null ],
    [ "makeXMLFragment", "group__xml__functions.html#ga4c393f08507c08c0fe2df2910c015e99", null ],
    [ "makeXMLString", "group__xml__functions.html#gadc4a3e7a509428d15133201d8dbe3f4b", null ],
    [ "makeXMLString", "group__xml__functions.html#ga8f63aa3edc95a323192a9b8d76329ef0", null ],
    [ "parse_xml", "group__xml__functions.html#gac5829d2b7d573fbd765f8618d556be3d", null ],
    [ "parse_xml_with_relaxng", "group__xml__functions.html#ga604d8cf9409f7d31fbf320476fb08dd0", null ],
    [ "parse_xml_with_schema", "group__xml__functions.html#gac1259f7b56045d13a8f528178c53617f", null ],
    [ "parseXML", "group__xml__functions.html#ga63f87398503d3763c5e9503dd0f48c86", null ],
    [ "parseXML", "group__xml__functions.html#gaf9992355e68589537fd988a2b9a57852", null ],
    [ "parseXMLAsData", "group__xml__functions.html#gab951588a77c89c57c50e653901f3f2cf", null ],
    [ "parseXMLAsData", "group__xml__functions.html#gae14ec9f58a0d859ab53f1a14b717c81f", null ],
    [ "parseXMLAsDataWithRelaxNG", "group__xml__functions.html#gae73fdba66557c31b734b570d4e5c4336", null ],
    [ "parseXMLAsDataWithSchema", "group__xml__functions.html#ga9513c1b9e4d33955cde47225385a1b1b", null ],
    [ "parseXMLWithRelaxNG", "group__xml__functions.html#gae23f485fb7a34fc6e424e7d352a889c8", null ],
    [ "parseXMLWithSchema", "group__xml__functions.html#ga28c44488e50530f01bc5a0dff740ac22", null ]
];
